summaryrefslogtreecommitdiffstats
path: root/qtjava/javalib/org/kde/qt/qtjava.java
diff options
context:
space:
mode:
Diffstat (limited to 'qtjava/javalib/org/kde/qt/qtjava.java')
-rw-r--r--qtjava/javalib/org/kde/qt/qtjava.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/qtjava/javalib/org/kde/qt/qtjava.java b/qtjava/javalib/org/kde/qt/qtjava.java
index 8547776c..4ce02b93 100644
--- a/qtjava/javalib/org/kde/qt/qtjava.java
+++ b/qtjava/javalib/org/kde/qt/qtjava.java
@@ -77,7 +77,7 @@ public class qtjava {
qtKeyToJavaMap (tricky!).
So it is useful to be able to force the early removal of an entry, when the C++
- instance has a known lifetime (eg a QEvent after its event handler has
+ instance has a known lifetime (eg a TQEvent after its event handler has
returned).
*/
public static void removeObjectForQtKey(long qt) {
@@ -88,7 +88,7 @@ public class qtjava {
/** Allocates an instance of a class without initializing it */
private native static Object allocateInstance(Class cls) throws InstantiationException, IllegalAccessException;
/** If the C++ qt instance is an instance of QObject, then
use the Qt runtime meta-data to retrieve the class name.
If there is a Java class with the same name, then return
a Class object for that class. Otherwise, just return the
@@ -115,7 +115,7 @@ public class qtjava {
}
if (QtSupport.class.isAssignableFrom(aClass)) {
- if (QObject.class.isAssignableFrom(aClass)) {
+ if (TQObject.class.isAssignableFrom(aClass)) {
aClass = qtjava.classFromQtMetaData(aClass, aClass.getName(), qt);
}
@@ -247,11 +247,11 @@ public class qtjava {
/** Returns a new C++ JavaSlot proxy instance, to receive signals
and invoke the target Java slot */
- private native static long newJavaSlot(QObject receiver, String member);
+ private native static long newJavaSlot(TQObject receiver, String member);
/** Looks up a 'qt instance/slot name' key and returns the corresponding
JavaSlot instance */
- public static long slotForReceiver(long qt, QObject receiver, String slot) {
+ public static long slotForReceiver(long qt, TQObject receiver, String slot) {
String normalizedSlot = toNormalizedTypeSignature(slot);
String key = (Long.toString(qt) + normalizedSlot).intern();
Long result = (Long) qtSlotDictionary.get(key);
@@ -88,7 +88,7 @@ public class qtjava {
/** Allocates an instance of a class without initializing it */
private native static Object allocateInstance(Class cls) throws InstantiationException, IllegalAccessException;
- /** If the C++ qt instance is an instance of QObject, then
+ /** If the C++ qt instance is an instance of TQObject, then
use the Qt runtime meta-data to retrieve the class name.
If there is a Java class with the same name, then return